def mass_energy(mass: int | float):
    c = 299792458
    if mass < 0:
        raise ValueError("Mass cannot be negative!")
    else:
        e = mass * c ** 2
        return e
    
def sensible_heat(t, m, c):
    if m < 0 or c < 0:
        raise ValueError("Mass or Heat cannot be negative!")
    return t * m * c


def hypercube_faces(d):
    if d < 0:
        raise ValueError("Dimension cannot is 0!")
    else:
        return ((d * (d - 1)) / 2) * (2 ** (d - 2))
    
def hypercube_edges(d):
    if d < 0:
        raise ValueError("Dimension cannot is 0!")
    else:
        return (2 ** (d - 1)) * d
    
def hypercube_vertices(d):
    if d < 0:
        raise ValueError("Dimension cannot is 0!")
    else:
        return 2 ** d


def babilonic(tries: int | float, sqrt: int | float, approx: int | float):
    c = approx
    for _ in range(tries):
        c = (1 / 2) * (c + (sqrt / c))
    return c

def pitagoras(a: int | float, b: int | float):
    return (a ** 2) + (b ** 2)


def fatorial(n: int):
    f = 1
    for i in range(f, n + 1):
        f *= i
    return f

def termial(n):
    return (n * (n + 1)) // 2

def plus_list(terms: list[float]):
    return sum(terms)

def inverse(n):
    return 1 / n